package com.lc.jdbc.dao.impl;

import com.lc.jdbc.bean.Dept;
import com.lc.jdbc.dao.DeptDao;
import com.lc.utils.DButils;
import com.lc.utils.DruidUtils;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

public class DeptDaoImpl implements DeptDao {
    @Override
    public Dept getById(Integer id) throws SQLException {

        //获取链接
        Connection connection = DButils.getConnection();
        //Sql
        String sql = " select * from tb_dept where id = ? ";
        //获取执行对象
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        //设置参数
        preparedStatement.setInt(1,id);
        //结果
        ResultSet resultSet = preparedStatement.executeQuery();
        Dept dept = null;
        //循环
        while (resultSet.next()){
            dept = new Dept();
            dept.setId(resultSet.getInt("id"));
            dept.setDeptName(resultSet.getString("dept_name"));
            dept.setOrdered(resultSet.getInt("ordered"));
            dept.setDescription(resultSet.getString("description"));
            dept.setStatus(resultSet.getInt("status"));
        }
        return dept;
    }

    @Override
    public List<Dept> getAll() throws SQLException {
        //获取链接
        Connection connection = DButils.getConnection();
        //Sql
        String sql = " select * from tb_dept ";
        //获取执行对象
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        //结果
        ResultSet resultSet = preparedStatement.executeQuery();
        List<Dept> list = new ArrayList<>();
        //循环
        while (resultSet.next()){
            Dept dept = new Dept();
            dept.setId(resultSet.getInt("id"));
            dept.setDeptName(resultSet.getString("dept_name"));
            dept.setOrdered(resultSet.getInt("ordered"));
            dept.setDescription(resultSet.getString("description"));
            dept.setStatus(resultSet.getInt("status"));
            //添加到集合
            list.add(dept);
        }
        return list;
    }

    @Override
    public int update(Dept dept) throws SQLException {
        //获取链接
        Connection connection = DButils.getConnection();
        //sql
        String sql =" update tb_dept " +
                " set dept_name = ?,ordered = ?,description = ?,status = ?" +
                " where id = ? ";
        //获取执行对象
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        //设置
        preparedStatement.setString(1,dept.getDeptName());
        preparedStatement.setInt(2,dept.getOrdered());
        preparedStatement.setString(3,dept.getDescription());
        preparedStatement.setInt(4,dept.getStatus());
        preparedStatement.setInt(5,dept.getId());

        //执行
        return preparedStatement.executeUpdate();
    }

    @Override
    public int add(Dept dept) throws SQLException {

        //获取链接
        Connection connection = DButils.getConnection();
        //sql
        String sql =" INSERT INTO `vipq2`.`tb_dept` ( `dept_name`, `ordered`, `description`, `status`) " +
                " VALUES (?, ?, ?, ?); ";
        //获取执行对象
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        //设置
        preparedStatement.setString(1,dept.getDeptName());
        preparedStatement.setInt(2,dept.getOrdered());
        preparedStatement.setString(3,dept.getDescription());
        preparedStatement.setInt(4,dept.getStatus());

        //执行
        return preparedStatement.executeUpdate();
    }

    @Override
    public int delete(Integer id) throws SQLException {
        //获取链接
        Connection connection = DruidUtils.getConnection();
        //sql
        String sql = " delete from tb_dept where id = ?  ";
        //获取执行对象
        PreparedStatement preparedStatement = connection.prepareStatement(sql);
        //设置参数
        preparedStatement.setInt(1,id);
        //执行
        return preparedStatement.executeUpdate();
    }
}